#!/usr/bin/python
import sys
import os

from csc_interface import *
from csc_convert import *
from csc_edit import *
from csc_globals import *

functions = {"extract-mac-profile":extract, "store-mac-profile":store, "convert-profile":convert,
             "remove-weapon":wrem, "add-weapon":wadd, "remove-item":irem, "add-item":iadd,
             "set-flag":None, "unset-flag":None, "advanced-edit":edit, "interactive":getUserInput,
             "clean-temp-file":deleteTemp, "advanced-interactive":interactiveEditMode, "choose-file":chooseMainFile}

def main():
    tasks = parseInput()
    if debugMode: print tasks
    while tasks != []:
        curTask = tasks[0]
        tasks = tasks[1:]
        if "interactive" in curTask[0]:
            curTask += (tasks,)
        functions[curTask[0]](*curTask[1:])
        if debugMode: print tasks

def parseInput():
    """Get command-line input"""
    tasks = []
    currentArg = ""
    if len(sys.argv) == 1:
        tasks.append( ("interactive",) )
    i = 1
    curFile = ""
    while i < len(sys.argv):
        if sys.argv[i] == '-?' or sys.argv[i] == '-h' or sys.argv[i] == '/?':
            displayUsage()
            sys.exit()
        if sys.argv[i] == '-?x' or sys.argv[i] == '-hx':
            advancedHelp()
            sys.exit()
        if sys.argv[i] == '-file' or sys.argv[i] == '-edit':
            curFile = sys.argv[i+1]
            i += 2
#        elif sys.argv[i] == '-e':
#            x = ""
#            try:
#                if sys.argv[i+1] == '@': x = defPLPath
#                else: x = sys.argv[i+1]
#                tasks.append( ("extract-mac-profile",x,sys.argv[i+2]) )
#            except:
#                print "Error: Source or destination not specified for extraction."
#                sys.exit()
#            i += 3
#        elif sys.argv[i] == '-s':
#            try:
#                if sys.argv[i+2] == '@': x = defPLPath
#                else: x = sys.argv[i+2]
#                tasks.append( ("store-mac-profile",sys.argv[i+1],x) )
#            except:
#                print "Error: Source or destination not specified for storing profile."
#                sys.exit()
#            i += 3
        elif sys.argv[i] == '-ec' or sys.argv[i] == '-e':
            try:
                if sys.argv[i+1] == '@': pl = defPLPath
                else: pl = sys.argv[i+1]
                tasks.append( ("extract-mac-profile",pl,".pycs_temp") )
                tasks.append( ("convert-profile",".pycs_temp",sys.argv[i+2]) )
                tasks.append( ("clean-temp-file",".pycs_temp") )
            except:
                print "Error: Source or destination not specified for extraction."
                sys.exit()
            i += 3
        elif sys.argv[i] == '-cs' or sys.argv[i] == '-s':
            try:
                if sys.argv[i+2] == '@': pl = defPLPath
                else: pl = sys.argv[i+2]
                tasks.append( ("convert-profile",sys.argv[i+1],".pycs_temp") )
                tasks.append( ("store-mac-profile",".pycs_temp",pl) )
                tasks.append( ("clean-temp-file",".pycs_temp") )
            except:
                print "Error: Source or destination not specified for storing profile."
                sys.exit()
            i += 3
        elif sys.argv[i][:2] == '-w':
            if curFile == "": specifyFileError()
            arg = sys.argv[i][2:]
            tasks.append( ("remove-weapon", int(arg), curFile) )
            i += 1
        elif sys.argv[i][:2] == '+w':
            # Syntax: +w4@3=12,100 : weapon@level=energy,maxammo
            if curFile == "": specifyFileError()
            args = sys.argv[i][2:]
            try:
                args = args.split('@')
                args[1:] = args[1].split('=')
                args[2:] = args[2].split(',')
                if debugMode: print args
                task = ("add-weapon",)
                for x in args:
                    if debugMode: print x
                    task += (int(x),)
                task += (curFile,)
                if debugMode: print task
                tasks.append( task )
            except:
                print "Syntax error in add weapon directive."
                if debugMode:
                    print sys.exc_type
                    print sys.exc_value
                    print "Line", sys.exc_traceback.tb_lineno
                sys.exit()
            i += 1
        elif sys.argv[i][:2] == '-i':
            if curFile == "": specifyFileError()
            arg = sys.argv[i][2:]
            tasks.append( ("remove-item", int(arg), curFile) )
            i += 1
        elif sys.argv[i][:2] == '+i':
            if curFile == "": specifyFileError()
            arg = sys.argv[i][2:]
            if arg[-1] == '*':
                task = ("add-item", int(arg[:-1]), True, curFile)
            else:
                task = ("add-item", int(arg), False, curFile)
            tasks.append(task)
            i += 1
        elif sys.argv[i][:2] == '-f':
            if curFile == "": specifyFileError()
            arg = sys.argv[i][2:]
            tasks.append( ("unset-flag", curFile) )
            i += 1
        elif sys.argv[i][:2] == '+f':
            if curFile == "": specifyFileError()
            arg = sys.argv[i][2:]
            tasks.append( ("set-flag", curFile) )
            i += 1
        elif sys.argv[i] == '-x':
            if curFile == "": specifyFileError()
            i += 1
            attrs = {}
            try:
                while sys.argv[i] != '-':
                    arg = sys.argv[i].split('=')
                    try:
                        attrs[arg[0]] = int(arg[1])
                        attrs[arg[0]] = chr(attrs[arg[0]])
                    except:
                        attrs[arg[0]] = arg[1]
                    i += 1
            except:
                print "Advanced editing section was not terminated by -"
                sys.exit()
            if attrs != {}:
                tasks.append( ("advanced-edit", attrs, curFile) )
            i += 1
        else:
            print "Invalid argument %s" % sys.argv[i]
            sys.exit()
    return tasks
#    if len(sys.argv) > 1:
#        if sys.argv[1] == "-?" or sys.argv[1] == "-h" or sys.argv[1] == "-h":
#            print "Usage:", sys.argv[0], "name [opt] [source [dest]]"
#            sys.exit()
#        elif sys.argv[1] == "-e":
#            mode = "extract-mac-profile"
#            source = sys.argv[2] if len(sys.argv) > 2 else "com.nakiwo.doukutsu.plist"
#            if sys.platform == "darwin" and '/' not in source and '\\' not in source:
#                source = "~/Library/Preferences/" + source;
#            dest = sys.argv[3] if len(sys.argv) > 3 else "profile.dsv"
#        elif sys.argv[1] == "-s":
#            mode = "store-mac-profile"
#            source = sys.argv[2] if len(sys.argv) > 2 else "profile.dsv"
#            dest = sys.argv[3] if len(sys.argv) > 3 else defPLPath
#        elif sys.argv[1] == "-m":
#            mode = "win-to-mac"
#            source = sys.argv[2] if len(sys.argv) > 2 else "profile.dat"
#            dest = sys.argv[3] if len(sys.argv) > 3 else "profile.dsv"
#        elif sys.argv[1] == "-w":
#            mode = "mac-to-win"
#            source = sys.argv[2] if len(sys.argv) > 2 else "profile.dsv"
#            dest = sys.argv[3] if len(sys.argv) > 3 else "profile.dat"
#        else:
#            source = sys.argv[2]
#            if len(sys.argv) > 3: dest = sys.argv[3]
#    return mode

main()
